# Zenplate Overview

Zenplate is a command line tool that renders Jinja templates with a set of variables.


## Features

- Single file templating - render a single file with variables
- Directory templating - render all files in a directory, including file and directory names
- Plugin system - extend the functionality of Zenplate with custom data, filter, and test plugins

## Ideas on how to start using Zenplate

- In place of a heavier templating tool like cookiecutter or Ansible.
- Generate a README.md or pyproject.toml file for a new project
- Generate a directory full of boilerplate code, keeping the structure consistent.
- Write a script to send you an Zenplate templated email based on system information.
- Develop your own data plugins to pull data from databases, APIs, or other sources.

## Getting Started

- See [Quickstart](quickstart.md) for a quick guide on how to get started with Zenplate.
- Look over the [CLI Reference](cli.md) for a full list of options and arguments.
- Check out the [Configuration Reference](config.md) for a full list of configuration options.